@@ -1,7 +1,7 @@
 #
 # This file is part of App-Cme
 #
-# This software is Copyright (c) 2014-2018 by Dominique Dumont.
+# This software is Copyright (c) 2014-2020 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -10,7 +10,7 @@
 # ABSTRACT: Edit the configuration of an application
 
 package App::Cme::Command::edit ;
-$App::Cme::Command::edit::VERSION = '1.029';
+$App::Cme::Command::edit::VERSION = '1.031';
 use strict;
 use warnings;
 use 5.10.1;
@@ -103,7 +103,7 @@ sub execute {
     elsif ( $ui_type eq 'tk' ) {
         die "cannot run Tk interface: Config::Model::TkUI is not installed, please use curses or shell or simple ui\n"
             unless $has_tk;
-        $self ->run_tk_ui ( $root, $opt);
+        $self ->run_tk_ui ( $inst, $opt);
     }
     else {
         die "Unsupported user interface: $ui_type";
@@ -124,7 +124,7 @@ App::Cme::Command::edit - Edit the configuration of an application
 
 =head1 VERSION
 
-version 1.029
+version 1.031
 
 =head1 SYNOPSIS
 
@@ -191,7 +191,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014-2018 by Dominique Dumont.
+This software is Copyright (c) 2014-2020 by Dominique Dumont.
 
 This is free software, licensed under:
 
