@@ -1,7 +1,7 @@
 #
 # This file is part of App-Cme
 #
-# This software is Copyright (c) 2014-2018 by Dominique Dumont.
+# This software is Copyright (c) 2014-2020 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -10,7 +10,7 @@
 # ABSTRACT: Update the configuration of an application
 
 package App::Cme::Command::update ;
-$App::Cme::Command::update::VERSION = '1.030';
+$App::Cme::Command::update::VERSION = '1.031';
 use strict;
 use warnings;
 use 5.10.1;
@@ -68,7 +68,7 @@ sub execute {
 
     if ($opt->{edit}) {
         say join("\n", grep {defined $_} @msgs );
-        $self->run_tk_ui ( $inst->config_root, $opt);
+        $self->run_tk_ui ( $inst, $opt);
     }
     else {
         $self->save($inst,$opt) ;
@@ -91,7 +91,7 @@ App::Cme::Command::update - Update the configuration of an application
 
 =head1 VERSION
 
-version 1.030
+version 1.031
 
 =head1 SYNOPSIS
 
@@ -131,7 +131,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014-2018 by Dominique Dumont.
+This software is Copyright (c) 2014-2020 by Dominique Dumont.
 
 This is free software, licensed under:
 
