@@ -1,7 +1,7 @@
 #
 # This file is part of App-Cme
 #
-# This software is Copyright (c) 2017 by Dominique Dumont.
+# This software is Copyright (c) 2014-2020 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -10,12 +10,12 @@
 #ABSTRACT: Common methods for App::Cme
 
 package App::Cme::Common;
-$App::Cme::Common::VERSION = '1.026';
+$App::Cme::Common::VERSION = '1.031';
 use strict;
 use warnings;
 use 5.10.1;
 
-use Config::Model 2.116;
+use Config::Model 2.124 qw/initialize_log4perl/;
 use Config::Model::Lister;
 use Pod::POM;
 use Pod::POM::View::Text;
@@ -40,7 +40,8 @@ sub cme_global_options {
       # to be deprecated
       [ "canonical!"         => "write back config data according to canonical order" ],
       [ "trace|stack-trace!" => "Provides a full stack trace when exiting on error"],
-      [ "verbose=s"          => "Verbosity level (1, 2, 3  or info, debug, trace)"],
+      [ "verbose!"           => "Show what's going on"],
+      [ "quiet"              => "Suppress all output except error messages"],
       # no bundling
       { getopt_conf => [ qw/no_bundling/ ] }
   );
@@ -67,6 +68,12 @@ sub process_args {
 
     my ( $categories, $appli_info, $appli_map ) = Config::Model::Lister::available_models;
     my $application = shift @$args;
+    unless ($application) {
+        $self->usage_error(
+            "Missing application parameter. Run 'cme list' to get the "
+                . "list of installed cme applications\n"
+            );
+    }
 
     my $root_model = $appli_map->{$application};
     $root_model ||= $application if $opt->{try_app_as_model};
@@ -80,8 +87,6 @@ sub process_args {
             . "See the available models there: https://github.com/dod38fr/config-model/wiki/Available-models-and-backends\n";
     }
 
-    say "cme: using $root_model model" unless $opt->{quiet};
-
     my $command = (split('::', ref($self)))[-1] ;
 
     if ($appli_info->{$application}{require_config_file}
@@ -131,28 +136,12 @@ sub process_args {
 sub model {
     my ($self, $opt, $args) = @_;
 
-    my @levels = qw/WARN INFO DEBUG TRACE/;
-    my $optv = $opt->{verbose} ;
-
-    my $log_level;
-    if (defined $optv) {
-        if ($optv =~ /^\d$/) {
-            $log_level =  $levels[$opt->{verbose}];
-        }
-        else {
-            ($log_level) = grep { /^$optv/i } @levels;
-        }
-        if (not $log_level) {
-            die "unknown log level $optv. Must be 1 ,2, 3 or warn, info, debug, trace.\n" ;
-        }
-    }
-
-
     my %cm_args;
     $cm_args{model_dir} = $opt->{model_dir} if $opt->{model_dir};
-    $cm_args{log_level} = $log_level if $log_level;
 
     if (not $self->{_model}) {
+        initialize_log4perl( verbose => $opt->{_verbose} );
+
         my $model = $self->{_model} = Config::Model->new( %cm_args );
         push @store, $model;
     }
@@ -198,7 +187,7 @@ sub save {
 }
 
 sub run_tk_ui {
-    my ($self, $root, $opt) = @_;
+    my ($self, $instance, $opt) = @_;
 
     require Config::Model::TkUI;
     require Tk;
@@ -212,14 +201,13 @@ sub run_tk_ui {
     # Thanks to Jerome Quelin for the tip
     $mw->optionAdd( '*BorderWidth' => 1 );
 
-    my $cmu = $mw->ConfigModelUI(
-        -root       => $root,
-    );
+    # -root parameter is deprecated
+    my $cmu = $mw->ConfigModelUI( -instance => $instance );
 
-    $root->instance->on_message_cb(sub{$cmu->show_message(@_);});
+    $instance->on_message_cb(sub{$cmu->show_message(@_);});
 
     if ($opt->{open_item}) {
-        my $obj = $root->grab($opt->{open_item});
+        my $obj = $instance->grab($opt->{open_item});
         $cmu->force_element_display($obj);
     }
 
@@ -251,7 +239,7 @@ sub get_documentation {
     my $sections = $pom->head1();
     my @ret ;
     foreach my $s (@$sections) {
-        push (@ret ,$s) if $s->title() =~ /DESCRIPTION|EXIT/;
+        push (@ret ,$s) if $s->title() =~ /DESCRIPTION|USAGE|OPTIONS|EXIT/;
     }
     return join ("", map { Pod::POM::View::Text->print($_)} @ret) . "Options:\n";;
 }
@@ -270,7 +258,7 @@ App::Cme::Common - Common methods for App::Cme
 
 =head1 VERSION
 
-version 1.026
+version 1.031
 
 =head1 SYNOPSIS
 
@@ -286,7 +274,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2017 by Dominique Dumont.
+This software is Copyright (c) 2014-2020 by Dominique Dumont.
 
 This is free software, licensed under:
 
